@@ -1,7 +1,7 @@
 #!/bin/bash
 # test if the reported minimal size of mkfs.btrfs is valid
 
-source "$TEST_TOP/common"
+source "$TEST_TOP/common" || exit
 
 check_prereq mkfs.btrfs
 check_prereq btrfs
@@ -39,19 +39,6 @@ do_test -n 16k	-m single	-d dup
 do_test -n 16k	-m dup		-d single
 do_test -n 16k	-m dup		-d dup
 
-# Temporary: disable the following tests as they fail inside travis but run
-# fine otherwise. This is probably caused by kernel version, 4.4 fails and 4.14
-# is ok.
-#
-# root_helper mount -t btrfs -o loop /home/travis/build/kdave/btrfs-progs/tests/test.img /home/travis/build/kdave/btrfs-progs/tests/mnt
-# mount: No space left on device
-# failed: root_helper mount -t btrfs -o loop /home/travis/build/kdave/btrfs-progs/tests/test.img /home/travis/build/kdave/btrfs-progs/tests/mnt
-# test failed for case 010-minimal-size
-#
-if [ "$TRAVIS" = true ]; then
-	exit 0
-fi
-
 do_test -n 32k	-m single	-d single
 do_test -n 32k	-m single	-d dup
 do_test -n 32k	-m dup		-d single
